# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_qos_resp import (
    V0041OpenapiSlurmdbdQosResp,
)


class TestV0041OpenapiSlurmdbdQosResp(unittest.TestCase):
    """V0041OpenapiSlurmdbdQosResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdQosResp:
        """Test V0041OpenapiSlurmdbdQosResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdQosResp`
        """
        model = V0041OpenapiSlurmdbdQosResp()
        if include_optional:
            return V0041OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner.v0_0_41_openapi_slurmdbd_config_resp_qos_inner(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = [

                                                ],
                                            account = [

                                                ],
                                            user = [

                                                ], ), ),
                                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                                        node = [

                                            ], ), ),
                                wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                            factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                                priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                                    set = True,
                                    infinite = True,
                                    number = 56, ), ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        usage_factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold(
                            set = True,
                            infinite = True,
                            number = 1.337, ), )
                    ],
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner.v0_0_41_openapi_slurmdbd_config_resp_qos_inner(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = [

                                                ],
                                            account = [

                                                ],
                                            user = [

                                                ], ), ),
                                    per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                                        node = [

                                            ], ), ),
                                wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                            factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                                priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                                    set = True,
                                    infinite = True,
                                    number = 56, ), ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        usage_factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold(
                            set = True,
                            infinite = True,
                            number = 1.337, ), )
                    ],
        )
        """

    def testV0041OpenapiSlurmdbdQosResp(self):
        """Test V0041OpenapiSlurmdbdQosResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_rollups import (
    V0041OpenapiSlurmdbdStatsRespStatisticsRollups,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_rpcs_inner import (
    V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_users_inner import (
    V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner,
)


class V0041OpenapiSlurmdbdStatsRespStatistics(BaseModel):
    """
    statistics
    """  # noqa: E501

    time_start: Optional[StrictInt] = Field(
        default=None, description="When data collection started (UNIX timestamp)"
    )
    rollups: Optional[V0041OpenapiSlurmdbdStatsRespStatisticsRollups] = None
    rpcs: Optional[List[V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner]] = Field(
        default=None, description="List of RPCs sent to the slurmdbd", alias="RPCs"
    )
    users: Optional[List[V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner]] = Field(
        default=None, description="List of users that issued RPCs"
    )
    __properties: ClassVar[List[str]] = ["time_start", "rollups", "RPCs", "users"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdStatsRespStatistics from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of rollups
        if self.rollups:
            _dict["rollups"] = self.rollups.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in rpcs (list)
        _items = []
        if self.rpcs:
            for _item_rpcs in self.rpcs:
                if _item_rpcs:
                    _items.append(_item_rpcs.to_dict())
            _dict["RPCs"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict["users"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdStatsRespStatistics from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "time_start": obj.get("time_start"),
                "rollups": V0041OpenapiSlurmdbdStatsRespStatisticsRollups.from_dict(
                    obj["rollups"]
                )
                if obj.get("rollups") is not None
                else None,
                "RPCs": [
                    V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner.from_dict(_item)
                    for _item in obj["RPCs"]
                ]
                if obj.get("RPCs") is not None
                else None,
                "users": [
                    V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner.from_dict(_item)
                    for _item in obj["users"]
                ]
                if obj.get("users") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_rollup_stats_monthly import V0042RollupStatsMonthly


class TestV0042RollupStatsMonthly(unittest.TestCase):
    """V0042RollupStatsMonthly unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042RollupStatsMonthly:
        """Test V0042RollupStatsMonthly
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042RollupStatsMonthly`
        """
        model = V0042RollupStatsMonthly()
        if include_optional:
            return V0042RollupStatsMonthly(
                count = 56,
                last_run = 56,
                duration = slurmrestpy.models.v0_0_42_rollup_stats_monthly_duration.v0_0_42_rollup_stats_monthly_duration(
                    last = 56,
                    max = 56,
                    time = 56, )
            )
        else:
            return V0042RollupStatsMonthly(
        )
        """

    def testV0042RollupStatsMonthly(self):
        """Test V0042RollupStatsMonthly"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_users_resp import V0041OpenapiUsersResp


class TestV0041OpenapiUsersResp(unittest.TestCase):
    """V0041OpenapiUsersResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiUsersResp:
        """Test V0041OpenapiUsersResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiUsersResp`
        """
        model = V0041OpenapiUsersResp()
        if include_optional:
            return V0041OpenapiUsersResp(
                users = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner(
                        administrator_level = [
                            'Not Set'
                            ],
                        associations = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_associations_inner.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_associations_inner(
                                account = '',
                                cluster = '',
                                partition = '',
                                user = '',
                                id = 56, )
                            ],
                        coordinators = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner(
                                name = '',
                                direct = True, )
                            ],
                        default = slurmrestpy.models.v0_0_40_user_default.v0_0_40_user_default(
                            account = '',
                            wckey = '', ),
                        flags = [
                            'NONE'
                            ],
                        name = '',
                        old_name = '',
                        wckeys = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner(
                                accounting = [
                                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner(
                                        allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                                            seconds = 56, ),
                                        id = 56,
                                        start = 56,
                                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_tres.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_TRES(
                                            type = '',
                                            name = '',
                                            id = 56,
                                            count = 56, ), )
                                    ],
                                cluster = '',
                                id = 56,
                                name = '',
                                user = '', )
                            ], )
                    ],
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiUsersResp(
                users = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner(
                        administrator_level = [
                            'Not Set'
                            ],
                        associations = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_associations_inner.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_associations_inner(
                                account = '',
                                cluster = '',
                                partition = '',
                                user = '',
                                id = 56, )
                            ],
                        coordinators = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner.v0_0_41_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner(
                                name = '',
                                direct = True, )
                            ],
                        default = slurmrestpy.models.v0_0_40_user_default.v0_0_40_user_default(
                            account = '',
                            wckey = '', ),
                        flags = [
                            'NONE'
                            ],
                        name = '',
                        old_name = '',
                        wckeys = [
                            slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner(
                                accounting = [
                                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner(
                                        allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                                            seconds = 56, ),
                                        id = 56,
                                        start = 56,
                                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_tres.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_TRES(
                                            type = '',
                                            name = '',
                                            id = 56,
                                            count = 56, ), )
                                    ],
                                cluster = '',
                                id = 56,
                                name = '',
                                user = '', )
                            ], )
                    ],
        )
        """

    def testV0041OpenapiUsersResp(self):
        """Test V0041OpenapiUsersResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0042_job_res_node import V0042JobResNode


class V0042JobResNodes(BaseModel):
    """
    V0042JobResNodes
    """  # noqa: E501

    count: Optional[StrictInt] = Field(
        default=None, description="Number of allocated nodes"
    )
    select_type: Optional[List[StrictStr]] = None
    list: Optional[StrictStr] = Field(
        default=None, description="Node(s) allocated to the job"
    )
    whole: Optional[StrictBool] = Field(
        default=None, description="Whether whole nodes were allocated"
    )
    allocation: Optional[List[V0042JobResNode]] = Field(
        default=None, description="Job resources for a node"
    )
    __properties: ClassVar[List[str]] = [
        "count",
        "select_type",
        "list",
        "whole",
        "allocation",
    ]

    @field_validator("select_type")
    def select_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["AVAILABLE", "ONE_ROW", "RESERVED"]):
                raise ValueError(
                    "each list item must be one of ('AVAILABLE', 'ONE_ROW', 'RESERVED')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042JobResNodes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in allocation (list)
        _items = []
        if self.allocation:
            for _item_allocation in self.allocation:
                if _item_allocation:
                    _items.append(_item_allocation.to_dict())
            _dict["allocation"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042JobResNodes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "count": obj.get("count"),
                "select_type": obj.get("select_type"),
                "list": obj.get("list"),
                "whole": obj.get("whole"),
                "allocation": [
                    V0042JobResNode.from_dict(_item) for _item in obj["allocation"]
                ]
                if obj.get("allocation") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0042_float64_no_val_struct import V0042Float64NoValStruct
from slurmrestpy.models.v0042_qos_limits import V0042QosLimits
from slurmrestpy.models.v0042_qos_preempt import V0042QosPreempt
from slurmrestpy.models.v0042_uint32_no_val_struct import V0042Uint32NoValStruct


class V0042Qos(BaseModel):
    """
    V0042Qos
    """  # noqa: E501

    description: Optional[StrictStr] = Field(
        default=None, description="Arbitrary description"
    )
    flags: Optional[List[StrictStr]] = None
    id: Optional[StrictInt] = Field(default=None, description="Unique ID")
    limits: Optional[V0042QosLimits] = None
    name: Optional[StrictStr] = Field(default=None, description="Name")
    preempt: Optional[V0042QosPreempt] = None
    priority: Optional[V0042Uint32NoValStruct] = None
    usage_factor: Optional[V0042Float64NoValStruct] = None
    usage_threshold: Optional[V0042Float64NoValStruct] = None
    __properties: ClassVar[List[str]] = [
        "description",
        "flags",
        "id",
        "limits",
        "name",
        "preempt",
        "priority",
        "usage_factor",
        "usage_threshold",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "NOT_SET",
                    "ADD",
                    "REMOVE",
                    "PARTITION_MINIMUM_NODE",
                    "PARTITION_MAXIMUM_NODE",
                    "PARTITION_TIME_LIMIT",
                    "ENFORCE_USAGE_THRESHOLD",
                    "NO_RESERVE",
                    "REQUIRED_RESERVATION",
                    "DENY_LIMIT",
                    "OVERRIDE_PARTITION_QOS",
                    "NO_DECAY",
                    "USAGE_FACTOR_SAFE",
                    "RELATIVE",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('NOT_SET', 'ADD', 'REMOVE', 'PARTITION_MINIMUM_NODE', 'PARTITION_MAXIMUM_NODE', 'PARTITION_TIME_LIMIT', 'ENFORCE_USAGE_THRESHOLD', 'NO_RESERVE', 'REQUIRED_RESERVATION', 'DENY_LIMIT', 'OVERRIDE_PARTITION_QOS', 'NO_DECAY', 'USAGE_FACTOR_SAFE', 'RELATIVE')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042Qos from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of limits
        if self.limits:
            _dict["limits"] = self.limits.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preempt
        if self.preempt:
            _dict["preempt"] = self.preempt.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        # override the default output from pydantic by calling `to_dict()` of usage_factor
        if self.usage_factor:
            _dict["usage_factor"] = self.usage_factor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of usage_threshold
        if self.usage_threshold:
            _dict["usage_threshold"] = self.usage_threshold.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042Qos from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "description": obj.get("description"),
                "flags": obj.get("flags"),
                "id": obj.get("id"),
                "limits": V0042QosLimits.from_dict(obj["limits"])
                if obj.get("limits") is not None
                else None,
                "name": obj.get("name"),
                "preempt": V0042QosPreempt.from_dict(obj["preempt"])
                if obj.get("preempt") is not None
                else None,
                "priority": V0042Uint32NoValStruct.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "usage_factor": V0042Float64NoValStruct.from_dict(obj["usage_factor"])
                if obj.get("usage_factor") is not None
                else None,
                "usage_threshold": V0042Float64NoValStruct.from_dict(
                    obj["usage_threshold"]
                )
                if obj.get("usage_threshold") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_acct_gather_energy import V0042AcctGatherEnergy


class TestV0042AcctGatherEnergy(unittest.TestCase):
    """V0042AcctGatherEnergy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042AcctGatherEnergy:
        """Test V0042AcctGatherEnergy
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042AcctGatherEnergy`
        """
        model = V0042AcctGatherEnergy()
        if include_optional:
            return V0042AcctGatherEnergy(
                average_watts = 56,
                base_consumed_energy = 56,
                consumed_energy = 56,
                current_watts = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                previous_consumed_energy = 56,
                last_collected = 56
            )
        else:
            return V0042AcctGatherEnergy(
        )
        """

    def testV0042AcctGatherEnergy(self):
        """Test V0042AcctGatherEnergy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner import (
    V0041OpenapiJobInfoRespJobsInner,
)


class TestV0041OpenapiJobInfoRespJobsInner(unittest.TestCase):
    """V0041OpenapiJobInfoRespJobsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiJobInfoRespJobsInner:
        """Test V0041OpenapiJobInfoRespJobsInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiJobInfoRespJobsInner`
        """
        model = V0041OpenapiJobInfoRespJobsInner()
        if include_optional:
            return V0041OpenapiJobInfoRespJobsInner(
                account = '',
                accrue_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time.v0_0_41_openapi_job_info_resp_jobs_inner_accrue_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                admin_comment = '',
                allocating_node = '',
                array_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_array_job_id(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_task_id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_max_tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_array_max_tasks(
                    set = True,
                    infinite = True,
                    number = 56, ),
                array_task_string = '',
                association_id = 56,
                batch_features = '',
                batch_flag = True,
                batch_host = '',
                flags = [
                    'KILL_INVALID_DEPENDENCY'
                    ],
                burst_buffer = '',
                burst_buffer_state = '',
                cluster = '',
                cluster_features = '',
                command = '',
                comment = '',
                container = '',
                container_id = '',
                contiguous = True,
                core_spec = 56,
                thread_spec = 56,
                cores_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_cores_per_socket(
                    set = True,
                    infinite = True,
                    number = 56, ),
                billable_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres.v0_0_41_openapi_job_info_resp_jobs_inner_billable_tres(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                cpus_per_task = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task.v0_0_41_openapi_job_info_resp_jobs_inner_cpus_per_task(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_minimum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_maximum = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpu_frequency_governor = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor.v0_0_41_openapi_job_info_resp_jobs_inner_cpu_frequency_governor(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus_per_tres = '',
                cron = '',
                deadline = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_deadline.v0_0_41_openapi_job_info_resp_jobs_inner_deadline(
                    set = True,
                    infinite = True,
                    number = 56, ),
                delay_boot = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot.v0_0_41_openapi_job_info_resp_jobs_inner_delay_boot(
                    set = True,
                    infinite = True,
                    number = 56, ),
                dependency = '',
                derived_exit_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                        id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                eligible_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time.v0_0_41_openapi_job_info_resp_jobs_inner_eligible_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                end_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_end_time.v0_0_41_openapi_job_info_resp_jobs_inner_end_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                excluded_nodes = '',
                exit_code = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code.v0_0_41_openapi_job_info_resp_jobs_inner_exit_code(
                    status = [
                        'INVALID'
                        ],
                    return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                        id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        name = '', ), ),
                extra = '',
                failed_node = '',
                features = '',
                federation_origin = '',
                federation_siblings_active = '',
                federation_siblings_viable = '',
                gres_detail = [
                    ''
                    ],
                group_id = 56,
                group_name = '',
                het_job_id = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id.v0_0_41_openapi_job_info_resp_jobs_inner_het_job_id(
                    set = True,
                    infinite = True,
                    number = 56, ),
                het_job_id_set = '',
                het_job_offset = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset(
                    set = True,
                    infinite = True,
                    number = 56, ),
                job_id = 56,
                job_resources = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources(
                    select_type = [
                        'CPU'
                        ],
                    nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes(
                        count = 56,
                        list = '',
                        whole = True,
                        allocation = [
                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner(
                                index = 56,
                                name = '',
                                cpus = slurmrestpy.models.v0_0_42_job_res_node_cpus.v0_0_42_job_res_node_cpus(
                                    count = 56,
                                    used = 56, ),
                                memory = slurmrestpy.models.v0_0_42_job_res_node_memory.v0_0_42_job_res_node_memory(
                                    used = 56,
                                    allocated = 56, ),
                                sockets = [
                                    slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner(
                                        index = 56,
                                        cores = [
                                            slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner(
                                                index = 56,
                                                status = [
                                                    'INVALID'
                                                    ], )
                                            ], )
                                    ], )
                            ], ),
                    cpus = 56,
                    threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                job_size_str = [
                    ''
                    ],
                job_state = [
                    'PENDING'
                    ],
                last_sched_evaluation = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation.v0_0_41_openapi_job_info_resp_jobs_inner_last_sched_evaluation(
                    set = True,
                    infinite = True,
                    number = 56, ),
                licenses = '',
                mail_type = [
                    'BEGIN'
                    ],
                mail_user = '',
                max_cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_max_cpus(
                    set = True,
                    infinite = True,
                    number = 56, ),
                max_nodes = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes.v0_0_41_openapi_job_info_resp_jobs_inner_max_nodes(
                    set = True,
                    infinite = True,
                    number = 56, ),
                mcs_label = '',
                memory_per_tres = '',
                name = '',
                network = '',
                nodes = '',
                nice = 56,
                tasks_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_core(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_tres = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_tres(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_node(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_socket = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_socket(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks_per_board = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board.v0_0_41_openapi_job_info_resp_jobs_inner_tasks_per_board(
                    set = True,
                    infinite = True,
                    number = 56, ),
                cpus = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_cpus.v0_0_41_openapi_job_info_resp_jobs_inner_cpus(
                    set = True,
                    infinite = True,
                    number = 56, ),
                node_count = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_node_count.v0_0_41_openapi_job_info_resp_jobs_inner_node_count(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tasks = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_tasks.v0_0_41_openapi_job_info_resp_jobs_inner_tasks(
                    set = True,
                    infinite = True,
                    number = 56, ),
                partition = '',
                prefer = '',
                memory_per_cpu = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu(
                    set = True,
                    infinite = True,
                    number = 56, ),
                memory_per_node = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node(
                    set = True,
                    infinite = True,
                    number = 56, ),
                minimum_cpus_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node(
                    set = True,
                    infinite = True,
                    number = 56, ),
                minimum_tmp_disk_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node(
                    set = True,
                    infinite = True,
                    number = 56, ),
                power = slurmrestpy.models.v0_0_42_job_info_power.v0_0_42_job_info_power(
                    flags = [
                        null
                        ], ),
                preempt_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time.v0_0_41_openapi_job_info_resp_jobs_inner_preempt_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                preemptable_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time.v0_0_41_openapi_job_info_resp_jobs_inner_preemptable_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                pre_sus_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time.v0_0_41_openapi_job_info_resp_jobs_inner_pre_sus_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                hold = True,
                priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_priority(
                    set = True,
                    infinite = True,
                    number = 56, ),
                profile = [
                    'NOT_SET'
                    ],
                qos = '',
                reboot = True,
                required_nodes = '',
                minimum_switches = 56,
                requeue = True,
                resize_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time.v0_0_41_openapi_job_info_resp_jobs_inner_resize_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                restart_cnt = 56,
                resv_name = '',
                scheduled_nodes = '',
                selinux_context = '',
                shared = [
                    'none'
                    ],
                exclusive = [
                    'true'
                    ],
                oversubscribe = True,
                show_flags = [
                    'ALL'
                    ],
                sockets_per_board = 56,
                sockets_per_node = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node.v0_0_41_openapi_job_info_resp_jobs_inner_sockets_per_node(
                    set = True,
                    infinite = True,
                    number = 56, ),
                start_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_start_time.v0_0_41_openapi_job_info_resp_jobs_inner_start_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                state_description = '',
                state_reason = '',
                standard_error = '',
                standard_input = '',
                standard_output = '',
                submit_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time.v0_0_41_openapi_job_info_resp_jobs_inner_submit_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                suspend_time = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time.v0_0_41_openapi_job_info_resp_jobs_inner_suspend_time(
                    set = True,
                    infinite = True,
                    number = 56, ),
                system_comment = '',
                time_limit = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit(
                    set = True,
                    infinite = True,
                    number = 56, ),
                time_minimum = slurmrestpy.models.v0_0_41_job_desc_msg_time_minimum.v0_0_41_job_desc_msg_time_minimum(
                    set = True,
                    infinite = True,
                    number = 56, ),
                threads_per_core = slurmrestpy.models.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core.v0_0_41_openapi_job_info_resp_jobs_inner_threads_per_core(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres_bind = '',
                tres_freq = '',
                tres_per_job = '',
                tres_per_node = '',
                tres_per_socket = '',
                tres_per_task = '',
                tres_req_str = '',
                tres_alloc_str = '',
                user_id = 56,
                user_name = '',
                maximum_switch_wait_time = 56,
                wckey = '',
                current_working_directory = ''
            )
        else:
            return V0041OpenapiJobInfoRespJobsInner(
        )
        """

    def testV0041OpenapiJobInfoRespJobsInner(self):
        """Test V0041OpenapiJobInfoRespJobsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive,
)


class TestV0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive(
    unittest.TestCase
):
    """V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive:
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive`
        """
        model = V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive(
                set = True,
                infinite = True,
                number = 56
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive(self):
        """Test V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self

from slurmrestpy.models.v0042_float64_no_val_struct import V0042Float64NoValStruct
from slurmrestpy.models.v0042_job_info_power import V0042JobInfoPower
from slurmrestpy.models.v0042_job_res import V0042JobRes
from slurmrestpy.models.v0042_part_prio import V0042PartPrio
from slurmrestpy.models.v0042_process_exit_code_verbose import (
    V0042ProcessExitCodeVerbose,
)
from slurmrestpy.models.v0042_uint16_no_val_struct import V0042Uint16NoValStruct
from slurmrestpy.models.v0042_uint32_no_val_struct import V0042Uint32NoValStruct
from slurmrestpy.models.v0042_uint64_no_val_struct import V0042Uint64NoValStruct


class V0042JobInfo(BaseModel):
    """
    V0042JobInfo
    """  # noqa: E501

    account: Optional[StrictStr] = Field(
        default=None, description="Account associated with the job"
    )
    accrue_time: Optional[V0042Uint64NoValStruct] = None
    admin_comment: Optional[StrictStr] = Field(
        default=None, description="Arbitrary comment made by administrator"
    )
    allocating_node: Optional[StrictStr] = Field(
        default=None, description="Local node making the resource allocation"
    )
    array_job_id: Optional[V0042Uint32NoValStruct] = None
    array_task_id: Optional[V0042Uint32NoValStruct] = None
    array_max_tasks: Optional[V0042Uint32NoValStruct] = None
    array_task_string: Optional[StrictStr] = Field(
        default=None, description="String expression of task IDs in this record"
    )
    association_id: Optional[StrictInt] = Field(
        default=None, description="Unique identifier for the association"
    )
    batch_features: Optional[StrictStr] = Field(
        default=None, description="Features required for batch script's node"
    )
    batch_flag: Optional[StrictBool] = Field(
        default=None, description="True if batch job"
    )
    batch_host: Optional[StrictStr] = Field(
        default=None, description="Name of host running batch script"
    )
    flags: Optional[List[StrictStr]] = None
    burst_buffer: Optional[StrictStr] = Field(
        default=None, description="Burst buffer specifications"
    )
    burst_buffer_state: Optional[StrictStr] = Field(
        default=None, description="Burst buffer state details"
    )
    cluster: Optional[StrictStr] = Field(default=None, description="Cluster name")
    cluster_features: Optional[StrictStr] = Field(
        default=None, description="List of required cluster features"
    )
    command: Optional[StrictStr] = Field(default=None, description="Executed command")
    comment: Optional[StrictStr] = Field(default=None, description="Arbitrary comment")
    container: Optional[StrictStr] = Field(
        default=None, description="Absolute path to OCI container bundle"
    )
    container_id: Optional[StrictStr] = Field(
        default=None, description="OCI container ID"
    )
    contiguous: Optional[StrictBool] = Field(
        default=None, description="True if job requires contiguous nodes"
    )
    core_spec: Optional[StrictInt] = Field(
        default=None, description="Specialized core count"
    )
    thread_spec: Optional[StrictInt] = Field(
        default=None, description="Specialized thread count"
    )
    cores_per_socket: Optional[V0042Uint16NoValStruct] = None
    billable_tres: Optional[V0042Float64NoValStruct] = None
    cpus_per_task: Optional[V0042Uint16NoValStruct] = None
    cpu_frequency_minimum: Optional[V0042Uint32NoValStruct] = None
    cpu_frequency_maximum: Optional[V0042Uint32NoValStruct] = None
    cpu_frequency_governor: Optional[V0042Uint32NoValStruct] = None
    cpus_per_tres: Optional[StrictStr] = Field(
        default=None,
        description="Semicolon delimited list of TRES=# values indicating how many CPUs should be allocated for each specified TRES (currently only used for gres/gpu)",
    )
    cron: Optional[StrictStr] = Field(
        default=None, description="Time specification for scrontab job"
    )
    deadline: Optional[V0042Uint64NoValStruct] = None
    delay_boot: Optional[V0042Uint32NoValStruct] = None
    dependency: Optional[StrictStr] = Field(
        default=None,
        description="Other jobs that must meet certain criteria before this job can start",
    )
    derived_exit_code: Optional[V0042ProcessExitCodeVerbose] = None
    eligible_time: Optional[V0042Uint64NoValStruct] = None
    end_time: Optional[V0042Uint64NoValStruct] = None
    excluded_nodes: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of nodes that may not be used"
    )
    exit_code: Optional[V0042ProcessExitCodeVerbose] = None
    extra: Optional[StrictStr] = Field(
        default=None,
        description="Arbitrary string used for node filtering if extra constraints are enabled",
    )
    failed_node: Optional[StrictStr] = Field(
        default=None, description="Name of node that caused job failure"
    )
    features: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of features that are required"
    )
    federation_origin: Optional[StrictStr] = Field(
        default=None, description="Origin cluster's name (when using federation)"
    )
    federation_siblings_active: Optional[StrictStr] = Field(
        default=None, description="Active sibling job names"
    )
    federation_siblings_viable: Optional[StrictStr] = Field(
        default=None, description="Viable sibling job names"
    )
    gres_detail: Optional[List[StrictStr]] = None
    group_id: Optional[StrictInt] = Field(
        default=None, description="Group ID of the user that owns the job"
    )
    group_name: Optional[StrictStr] = Field(
        default=None, description="Group name of the user that owns the job"
    )
    het_job_id: Optional[V0042Uint32NoValStruct] = None
    het_job_id_set: Optional[StrictStr] = Field(
        default=None, description="Job ID range for all heterogeneous job components"
    )
    het_job_offset: Optional[V0042Uint32NoValStruct] = None
    job_id: Optional[StrictInt] = Field(default=None, description="Job ID")
    job_resources: Optional[V0042JobRes] = None
    job_size_str: Optional[List[StrictStr]] = None
    job_state: Optional[List[StrictStr]] = None
    last_sched_evaluation: Optional[V0042Uint64NoValStruct] = None
    licenses: Optional[StrictStr] = Field(
        default=None, description="License(s) required by the job"
    )
    mail_type: Optional[List[StrictStr]] = None
    mail_user: Optional[StrictStr] = Field(
        default=None, description="User to receive email notifications"
    )
    max_cpus: Optional[V0042Uint32NoValStruct] = None
    max_nodes: Optional[V0042Uint32NoValStruct] = None
    mcs_label: Optional[StrictStr] = Field(
        default=None, description="Multi-Category Security label on the job"
    )
    memory_per_tres: Optional[StrictStr] = Field(
        default=None,
        description="Semicolon delimited list of TRES=# values indicating how much memory in megabytes should be allocated for each specified TRES (currently only used for gres/gpu)",
    )
    name: Optional[StrictStr] = Field(default=None, description="Job name")
    network: Optional[StrictStr] = Field(
        default=None, description="Network specs for the job"
    )
    nodes: Optional[StrictStr] = Field(
        default=None, description="Node(s) allocated to the job"
    )
    nice: Optional[StrictInt] = Field(
        default=None, description="Requested job priority change"
    )
    tasks_per_core: Optional[V0042Uint16NoValStruct] = None
    tasks_per_tres: Optional[V0042Uint16NoValStruct] = None
    tasks_per_node: Optional[V0042Uint16NoValStruct] = None
    tasks_per_socket: Optional[V0042Uint16NoValStruct] = None
    tasks_per_board: Optional[V0042Uint16NoValStruct] = None
    cpus: Optional[V0042Uint32NoValStruct] = None
    node_count: Optional[V0042Uint32NoValStruct] = None
    tasks: Optional[V0042Uint32NoValStruct] = None
    partition: Optional[StrictStr] = Field(
        default=None, description="Partition assigned to the job"
    )
    prefer: Optional[StrictStr] = Field(
        default=None,
        description="Feature(s) the job requested but that are not required",
    )
    memory_per_cpu: Optional[V0042Uint64NoValStruct] = None
    memory_per_node: Optional[V0042Uint64NoValStruct] = None
    minimum_cpus_per_node: Optional[V0042Uint16NoValStruct] = None
    minimum_tmp_disk_per_node: Optional[V0042Uint32NoValStruct] = None
    power: Optional[V0042JobInfoPower] = None
    preempt_time: Optional[V0042Uint64NoValStruct] = None
    preemptable_time: Optional[V0042Uint64NoValStruct] = None
    pre_sus_time: Optional[V0042Uint64NoValStruct] = None
    hold: Optional[StrictBool] = Field(
        default=None, description="Hold (true) or release (false) job"
    )
    priority: Optional[V0042Uint32NoValStruct] = None
    priority_by_partition: Optional[List[V0042PartPrio]] = None
    profile: Optional[List[StrictStr]] = None
    qos: Optional[StrictStr] = Field(
        default=None,
        description="Quality of Service assigned to the job, if pending the QOS requested",
    )
    reboot: Optional[StrictBool] = Field(
        default=None, description="Node reboot requested before start"
    )
    required_nodes: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of required nodes"
    )
    required_switches: Optional[StrictInt] = Field(
        default=None, description="Maximum number of switches"
    )
    requeue: Optional[StrictBool] = Field(
        default=None, description="Determines whether the job may be requeued"
    )
    resize_time: Optional[V0042Uint64NoValStruct] = None
    restart_cnt: Optional[StrictInt] = Field(
        default=None, description="Number of job restarts"
    )
    resv_name: Optional[StrictStr] = Field(
        default=None, description="Name of reservation to use"
    )
    scheduled_nodes: Optional[StrictStr] = Field(
        default=None, description="List of nodes scheduled to be used for the job"
    )
    selinux_context: Optional[StrictStr] = Field(
        default=None, description="SELinux context"
    )
    shared: Optional[List[StrictStr]] = None
    sockets_per_board: Optional[StrictInt] = Field(
        default=None, description="Number of sockets per board required"
    )
    sockets_per_node: Optional[V0042Uint16NoValStruct] = None
    start_time: Optional[V0042Uint64NoValStruct] = None
    state_description: Optional[StrictStr] = Field(
        default=None, description="Optional details for state_reason"
    )
    state_reason: Optional[StrictStr] = Field(
        default=None, description="Reason for current Pending or Failed state"
    )
    standard_error: Optional[StrictStr] = Field(
        default=None, description="Path to stderr file"
    )
    standard_input: Optional[StrictStr] = Field(
        default=None, description="Path to stdin file"
    )
    standard_output: Optional[StrictStr] = Field(
        default=None, description="Path to stdout file"
    )
    submit_time: Optional[V0042Uint64NoValStruct] = None
    suspend_time: Optional[V0042Uint64NoValStruct] = None
    system_comment: Optional[StrictStr] = Field(
        default=None, description="Arbitrary comment from slurmctld"
    )
    time_limit: Optional[V0042Uint32NoValStruct] = None
    time_minimum: Optional[V0042Uint32NoValStruct] = None
    threads_per_core: Optional[V0042Uint16NoValStruct] = None
    tres_bind: Optional[StrictStr] = Field(
        default=None, description="Task to TRES binding directives"
    )
    tres_freq: Optional[StrictStr] = Field(
        default=None, description="TRES frequency directives"
    )
    tres_per_job: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated per job",
    )
    tres_per_node: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated per node",
    )
    tres_per_socket: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated per socket",
    )
    tres_per_task: Optional[StrictStr] = Field(
        default=None,
        description="Comma separated list of TRES=# values to be allocated per task",
    )
    tres_req_str: Optional[StrictStr] = Field(
        default=None, description="TRES requested by the job"
    )
    tres_alloc_str: Optional[StrictStr] = Field(
        default=None, description="TRES used by the job"
    )
    user_id: Optional[StrictInt] = Field(
        default=None, description="User ID that owns the job"
    )
    user_name: Optional[StrictStr] = Field(
        default=None, description="User name that owns the job"
    )
    maximum_switch_wait_time: Optional[StrictInt] = Field(
        default=None, description="Maximum time to wait for switches in seconds"
    )
    wckey: Optional[StrictStr] = Field(
        default=None, description="Workload characterization key"
    )
    current_working_directory: Optional[StrictStr] = Field(
        default=None, description="Working directory to use for the job"
    )
    __properties: ClassVar[List[str]] = [
        "account",
        "accrue_time",
        "admin_comment",
        "allocating_node",
        "array_job_id",
        "array_task_id",
        "array_max_tasks",
        "array_task_string",
        "association_id",
        "batch_features",
        "batch_flag",
        "batch_host",
        "flags",
        "burst_buffer",
        "burst_buffer_state",
        "cluster",
        "cluster_features",
        "command",
        "comment",
        "container",
        "container_id",
        "contiguous",
        "core_spec",
        "thread_spec",
        "cores_per_socket",
        "billable_tres",
        "cpus_per_task",
        "cpu_frequency_minimum",
        "cpu_frequency_maximum",
        "cpu_frequency_governor",
        "cpus_per_tres",
        "cron",
        "deadline",
        "delay_boot",
        "dependency",
        "derived_exit_code",
        "eligible_time",
        "end_time",
        "excluded_nodes",
        "exit_code",
        "extra",
        "failed_node",
        "features",
        "federation_origin",
        "federation_siblings_active",
        "federation_siblings_viable",
        "gres_detail",
        "group_id",
        "group_name",
        "het_job_id",
        "het_job_id_set",
        "het_job_offset",
        "job_id",
        "job_resources",
        "job_size_str",
        "job_state",
        "last_sched_evaluation",
        "licenses",
        "mail_type",
        "mail_user",
        "max_cpus",
        "max_nodes",
        "mcs_label",
        "memory_per_tres",
        "name",
        "network",
        "nodes",
        "nice",
        "tasks_per_core",
        "tasks_per_tres",
        "tasks_per_node",
        "tasks_per_socket",
        "tasks_per_board",
        "cpus",
        "node_count",
        "tasks",
        "partition",
        "prefer",
        "memory_per_cpu",
        "memory_per_node",
        "minimum_cpus_per_node",
        "minimum_tmp_disk_per_node",
        "power",
        "preempt_time",
        "preemptable_time",
        "pre_sus_time",
        "hold",
        "priority",
        "priority_by_partition",
        "profile",
        "qos",
        "reboot",
        "required_nodes",
        "required_switches",
        "requeue",
        "resize_time",
        "restart_cnt",
        "resv_name",
        "scheduled_nodes",
        "selinux_context",
        "shared",
        "sockets_per_board",
        "sockets_per_node",
        "start_time",
        "state_description",
        "state_reason",
        "standard_error",
        "standard_input",
        "standard_output",
        "submit_time",
        "suspend_time",
        "system_comment",
        "time_limit",
        "time_minimum",
        "threads_per_core",
        "tres_bind",
        "tres_freq",
        "tres_per_job",
        "tres_per_node",
        "tres_per_socket",
        "tres_per_task",
        "tres_req_str",
        "tres_alloc_str",
        "user_id",
        "user_name",
        "maximum_switch_wait_time",
        "wckey",
        "current_working_directory",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "KILL_INVALID_DEPENDENCY",
                    "NO_KILL_INVALID_DEPENDENCY",
                    "HAS_STATE_DIRECTORY",
                    "TESTING_BACKFILL",
                    "GRES_BINDING_ENFORCED",
                    "TEST_NOW_ONLY",
                    "SEND_JOB_ENVIRONMENT",
                    "SPREAD_JOB",
                    "PREFER_MINIMUM_NODE_COUNT",
                    "JOB_KILL_HURRY",
                    "SKIP_TRES_STRING_ACCOUNTING",
                    "SIBLING_CLUSTER_UPDATE_ONLY",
                    "HETEROGENEOUS_JOB",
                    "EXACT_TASK_COUNT_REQUESTED",
                    "EXACT_CPU_COUNT_REQUESTED",
                    "TESTING_WHOLE_NODE_BACKFILL",
                    "TOP_PRIORITY_JOB",
                    "ACCRUE_COUNT_CLEARED",
                    "GRES_BINDING_DISABLED",
                    "JOB_WAS_RUNNING",
                    "JOB_ACCRUE_TIME_RESET",
                    "CRON_JOB",
                    "EXACT_MEMORY_REQUESTED",
                    "USING_DEFAULT_ACCOUNT",
                    "USING_DEFAULT_PARTITION",
                    "USING_DEFAULT_QOS",
                    "USING_DEFAULT_WCKEY",
                    "DEPENDENT",
                    "MAGNETIC",
                    "PARTITION_ASSIGNED",
                    "BACKFILL_ATTEMPTED",
                    "SCHEDULING_ATTEMPTED",
                    "STEPMGR_ENABLED",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('KILL_INVALID_DEPENDENCY', 'NO_KILL_INVALID_DEPENDENCY', 'HAS_STATE_DIRECTORY', 'TESTING_BACKFILL', 'GRES_BINDING_ENFORCED', 'TEST_NOW_ONLY', 'SEND_JOB_ENVIRONMENT', 'SPREAD_JOB', 'PREFER_MINIMUM_NODE_COUNT', 'JOB_KILL_HURRY', 'SKIP_TRES_STRING_ACCOUNTING', 'SIBLING_CLUSTER_UPDATE_ONLY', 'HETEROGENEOUS_JOB', 'EXACT_TASK_COUNT_REQUESTED', 'EXACT_CPU_COUNT_REQUESTED', 'TESTING_WHOLE_NODE_BACKFILL', 'TOP_PRIORITY_JOB', 'ACCRUE_COUNT_CLEARED', 'GRES_BINDING_DISABLED', 'JOB_WAS_RUNNING', 'JOB_ACCRUE_TIME_RESET', 'CRON_JOB', 'EXACT_MEMORY_REQUESTED', 'USING_DEFAULT_ACCOUNT', 'USING_DEFAULT_PARTITION', 'USING_DEFAULT_QOS', 'USING_DEFAULT_WCKEY', 'DEPENDENT', 'MAGNETIC', 'PARTITION_ASSIGNED', 'BACKFILL_ATTEMPTED', 'SCHEDULING_ATTEMPTED', 'STEPMGR_ENABLED')"
                )
        return value

    @field_validator("job_state")
    def job_state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "PENDING",
                    "RUNNING",
                    "SUSPENDED",
                    "COMPLETED",
                    "CANCELLED",
                    "FAILED",
                    "TIMEOUT",
                    "NODE_FAIL",
                    "PREEMPTED",
                    "BOOT_FAIL",
                    "DEADLINE",
                    "OUT_OF_MEMORY",
                    "LAUNCH_FAILED",
                    "REQUEUED",
                    "REQUEUE_HOLD",
                    "SPECIAL_EXIT",
                    "RESIZING",
                    "CONFIGURING",
                    "COMPLETING",
                    "STOPPED",
                    "RECONFIG_FAIL",
                    "POWER_UP_NODE",
                    "REVOKED",
                    "REQUEUE_FED",
                    "RESV_DEL_HOLD",
                    "SIGNALING",
                    "STAGE_OUT",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('PENDING', 'RUNNING', 'SUSPENDED', 'COMPLETED', 'CANCELLED', 'FAILED', 'TIMEOUT', 'NODE_FAIL', 'PREEMPTED', 'BOOT_FAIL', 'DEADLINE', 'OUT_OF_MEMORY', 'LAUNCH_FAILED', 'REQUEUED', 'REQUEUE_HOLD', 'SPECIAL_EXIT', 'RESIZING', 'CONFIGURING', 'COMPLETING', 'STOPPED', 'RECONFIG_FAIL', 'POWER_UP_NODE', 'REVOKED', 'REQUEUE_FED', 'RESV_DEL_HOLD', 'SIGNALING', 'STAGE_OUT')"
                )
        return value

    @field_validator("mail_type")
    def mail_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "BEGIN",
                    "END",
                    "FAIL",
                    "REQUEUE",
                    "TIME=100%",
                    "TIME=90%",
                    "TIME=80%",
                    "TIME=50%",
                    "STAGE_OUT",
                    "ARRAY_TASKS",
                    "INVALID_DEPENDENCY",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('BEGIN', 'END', 'FAIL', 'REQUEUE', 'TIME=100%', 'TIME=90%', 'TIME=80%', 'TIME=50%', 'STAGE_OUT', 'ARRAY_TASKS', 'INVALID_DEPENDENCY')"
                )
        return value

    @field_validator("profile")
    def profile_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["NOT_SET", "NONE", "ENERGY", "LUSTRE", "NETWORK", "TASK"]):
                raise ValueError(
                    "each list item must be one of ('NOT_SET', 'NONE', 'ENERGY', 'LUSTRE', 'NETWORK', 'TASK')"
                )
        return value

    @field_validator("shared")
    def shared_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["none", "oversubscribe", "user", "mcs", "topo"]):
                raise ValueError(
                    "each list item must be one of ('none', 'oversubscribe', 'user', 'mcs', 'topo')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042JobInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of accrue_time
        if self.accrue_time:
            _dict["accrue_time"] = self.accrue_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of array_job_id
        if self.array_job_id:
            _dict["array_job_id"] = self.array_job_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of array_task_id
        if self.array_task_id:
            _dict["array_task_id"] = self.array_task_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of array_max_tasks
        if self.array_max_tasks:
            _dict["array_max_tasks"] = self.array_max_tasks.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cores_per_socket
        if self.cores_per_socket:
            _dict["cores_per_socket"] = self.cores_per_socket.to_dict()
        # override the default output from pydantic by calling `to_dict()` of billable_tres
        if self.billable_tres:
            _dict["billable_tres"] = self.billable_tres.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpus_per_task
        if self.cpus_per_task:
            _dict["cpus_per_task"] = self.cpus_per_task.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpu_frequency_minimum
        if self.cpu_frequency_minimum:
            _dict["cpu_frequency_minimum"] = self.cpu_frequency_minimum.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpu_frequency_maximum
        if self.cpu_frequency_maximum:
            _dict["cpu_frequency_maximum"] = self.cpu_frequency_maximum.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpu_frequency_governor
        if self.cpu_frequency_governor:
            _dict["cpu_frequency_governor"] = self.cpu_frequency_governor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of deadline
        if self.deadline:
            _dict["deadline"] = self.deadline.to_dict()
        # override the default output from pydantic by calling `to_dict()` of delay_boot
        if self.delay_boot:
            _dict["delay_boot"] = self.delay_boot.to_dict()
        # override the default output from pydantic by calling `to_dict()` of derived_exit_code
        if self.derived_exit_code:
            _dict["derived_exit_code"] = self.derived_exit_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of eligible_time
        if self.eligible_time:
            _dict["eligible_time"] = self.eligible_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of end_time
        if self.end_time:
            _dict["end_time"] = self.end_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of exit_code
        if self.exit_code:
            _dict["exit_code"] = self.exit_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of het_job_id
        if self.het_job_id:
            _dict["het_job_id"] = self.het_job_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of het_job_offset
        if self.het_job_offset:
            _dict["het_job_offset"] = self.het_job_offset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of job_resources
        if self.job_resources:
            _dict["job_resources"] = self.job_resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_sched_evaluation
        if self.last_sched_evaluation:
            _dict["last_sched_evaluation"] = self.last_sched_evaluation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of max_cpus
        if self.max_cpus:
            _dict["max_cpus"] = self.max_cpus.to_dict()
        # override the default output from pydantic by calling `to_dict()` of max_nodes
        if self.max_nodes:
            _dict["max_nodes"] = self.max_nodes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks_per_core
        if self.tasks_per_core:
            _dict["tasks_per_core"] = self.tasks_per_core.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks_per_tres
        if self.tasks_per_tres:
            _dict["tasks_per_tres"] = self.tasks_per_tres.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks_per_node
        if self.tasks_per_node:
            _dict["tasks_per_node"] = self.tasks_per_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks_per_socket
        if self.tasks_per_socket:
            _dict["tasks_per_socket"] = self.tasks_per_socket.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks_per_board
        if self.tasks_per_board:
            _dict["tasks_per_board"] = self.tasks_per_board.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpus
        if self.cpus:
            _dict["cpus"] = self.cpus.to_dict()
        # override the default output from pydantic by calling `to_dict()` of node_count
        if self.node_count:
            _dict["node_count"] = self.node_count.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks
        if self.tasks:
            _dict["tasks"] = self.tasks.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory_per_cpu
        if self.memory_per_cpu:
            _dict["memory_per_cpu"] = self.memory_per_cpu.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memory_per_node
        if self.memory_per_node:
            _dict["memory_per_node"] = self.memory_per_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of minimum_cpus_per_node
        if self.minimum_cpus_per_node:
            _dict["minimum_cpus_per_node"] = self.minimum_cpus_per_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of minimum_tmp_disk_per_node
        if self.minimum_tmp_disk_per_node:
            _dict["minimum_tmp_disk_per_node"] = (
                self.minimum_tmp_disk_per_node.to_dict()
            )
        # override the default output from pydantic by calling `to_dict()` of power
        if self.power:
            _dict["power"] = self.power.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preempt_time
        if self.preempt_time:
            _dict["preempt_time"] = self.preempt_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preemptable_time
        if self.preemptable_time:
            _dict["preemptable_time"] = self.preemptable_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pre_sus_time
        if self.pre_sus_time:
            _dict["pre_sus_time"] = self.pre_sus_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of priority
        if self.priority:
            _dict["priority"] = self.priority.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in priority_by_partition (list)
        _items = []
        if self.priority_by_partition:
            for _item_priority_by_partition in self.priority_by_partition:
                if _item_priority_by_partition:
                    _items.append(_item_priority_by_partition.to_dict())
            _dict["priority_by_partition"] = _items
        # override the default output from pydantic by calling `to_dict()` of resize_time
        if self.resize_time:
            _dict["resize_time"] = self.resize_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sockets_per_node
        if self.sockets_per_node:
            _dict["sockets_per_node"] = self.sockets_per_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of start_time
        if self.start_time:
            _dict["start_time"] = self.start_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of submit_time
        if self.submit_time:
            _dict["submit_time"] = self.submit_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of suspend_time
        if self.suspend_time:
            _dict["suspend_time"] = self.suspend_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_limit
        if self.time_limit:
            _dict["time_limit"] = self.time_limit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_minimum
        if self.time_minimum:
            _dict["time_minimum"] = self.time_minimum.to_dict()
        # override the default output from pydantic by calling `to_dict()` of threads_per_core
        if self.threads_per_core:
            _dict["threads_per_core"] = self.threads_per_core.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042JobInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account": obj.get("account"),
                "accrue_time": V0042Uint64NoValStruct.from_dict(obj["accrue_time"])
                if obj.get("accrue_time") is not None
                else None,
                "admin_comment": obj.get("admin_comment"),
                "allocating_node": obj.get("allocating_node"),
                "array_job_id": V0042Uint32NoValStruct.from_dict(obj["array_job_id"])
                if obj.get("array_job_id") is not None
                else None,
                "array_task_id": V0042Uint32NoValStruct.from_dict(obj["array_task_id"])
                if obj.get("array_task_id") is not None
                else None,
                "array_max_tasks": V0042Uint32NoValStruct.from_dict(
                    obj["array_max_tasks"]
                )
                if obj.get("array_max_tasks") is not None
                else None,
                "array_task_string": obj.get("array_task_string"),
                "association_id": obj.get("association_id"),
                "batch_features": obj.get("batch_features"),
                "batch_flag": obj.get("batch_flag"),
                "batch_host": obj.get("batch_host"),
                "flags": obj.get("flags"),
                "burst_buffer": obj.get("burst_buffer"),
                "burst_buffer_state": obj.get("burst_buffer_state"),
                "cluster": obj.get("cluster"),
                "cluster_features": obj.get("cluster_features"),
                "command": obj.get("command"),
                "comment": obj.get("comment"),
                "container": obj.get("container"),
                "container_id": obj.get("container_id"),
                "contiguous": obj.get("contiguous"),
                "core_spec": obj.get("core_spec"),
                "thread_spec": obj.get("thread_spec"),
                "cores_per_socket": V0042Uint16NoValStruct.from_dict(
                    obj["cores_per_socket"]
                )
                if obj.get("cores_per_socket") is not None
                else None,
                "billable_tres": V0042Float64NoValStruct.from_dict(obj["billable_tres"])
                if obj.get("billable_tres") is not None
                else None,
                "cpus_per_task": V0042Uint16NoValStruct.from_dict(obj["cpus_per_task"])
                if obj.get("cpus_per_task") is not None
                else None,
                "cpu_frequency_minimum": V0042Uint32NoValStruct.from_dict(
                    obj["cpu_frequency_minimum"]
                )
                if obj.get("cpu_frequency_minimum") is not None
                else None,
                "cpu_frequency_maximum": V0042Uint32NoValStruct.from_dict(
                    obj["cpu_frequency_maximum"]
                )
                if obj.get("cpu_frequency_maximum") is not None
                else None,
                "cpu_frequency_governor": V0042Uint32NoValStruct.from_dict(
                    obj["cpu_frequency_governor"]
                )
                if obj.get("cpu_frequency_governor") is not None
                else None,
                "cpus_per_tres": obj.get("cpus_per_tres"),
                "cron": obj.get("cron"),
                "deadline": V0042Uint64NoValStruct.from_dict(obj["deadline"])
                if obj.get("deadline") is not None
                else None,
                "delay_boot": V0042Uint32NoValStruct.from_dict(obj["delay_boot"])
                if obj.get("delay_boot") is not None
                else None,
                "dependency": obj.get("dependency"),
                "derived_exit_code": V0042ProcessExitCodeVerbose.from_dict(
                    obj["derived_exit_code"]
                )
                if obj.get("derived_exit_code") is not None
                else None,
                "eligible_time": V0042Uint64NoValStruct.from_dict(obj["eligible_time"])
                if obj.get("eligible_time") is not None
                else None,
                "end_time": V0042Uint64NoValStruct.from_dict(obj["end_time"])
                if obj.get("end_time") is not None
                else None,
                "excluded_nodes": obj.get("excluded_nodes"),
                "exit_code": V0042ProcessExitCodeVerbose.from_dict(obj["exit_code"])
                if obj.get("exit_code") is not None
                else None,
                "extra": obj.get("extra"),
                "failed_node": obj.get("failed_node"),
                "features": obj.get("features"),
                "federation_origin": obj.get("federation_origin"),
                "federation_siblings_active": obj.get("federation_siblings_active"),
                "federation_siblings_viable": obj.get("federation_siblings_viable"),
                "gres_detail": obj.get("gres_detail"),
                "group_id": obj.get("group_id"),
                "group_name": obj.get("group_name"),
                "het_job_id": V0042Uint32NoValStruct.from_dict(obj["het_job_id"])
                if obj.get("het_job_id") is not None
                else None,
                "het_job_id_set": obj.get("het_job_id_set"),
                "het_job_offset": V0042Uint32NoValStruct.from_dict(
                    obj["het_job_offset"]
                )
                if obj.get("het_job_offset") is not None
                else None,
                "job_id": obj.get("job_id"),
                "job_resources": V0042JobRes.from_dict(obj["job_resources"])
                if obj.get("job_resources") is not None
                else None,
                "job_size_str": obj.get("job_size_str"),
                "job_state": obj.get("job_state"),
                "last_sched_evaluation": V0042Uint64NoValStruct.from_dict(
                    obj["last_sched_evaluation"]
                )
                if obj.get("last_sched_evaluation") is not None
                else None,
                "licenses": obj.get("licenses"),
                "mail_type": obj.get("mail_type"),
                "mail_user": obj.get("mail_user"),
                "max_cpus": V0042Uint32NoValStruct.from_dict(obj["max_cpus"])
                if obj.get("max_cpus") is not None
                else None,
                "max_nodes": V0042Uint32NoValStruct.from_dict(obj["max_nodes"])
                if obj.get("max_nodes") is not None
                else None,
                "mcs_label": obj.get("mcs_label"),
                "memory_per_tres": obj.get("memory_per_tres"),
                "name": obj.get("name"),
                "network": obj.get("network"),
                "nodes": obj.get("nodes"),
                "nice": obj.get("nice"),
                "tasks_per_core": V0042Uint16NoValStruct.from_dict(
                    obj["tasks_per_core"]
                )
                if obj.get("tasks_per_core") is not None
                else None,
                "tasks_per_tres": V0042Uint16NoValStruct.from_dict(
                    obj["tasks_per_tres"]
                )
                if obj.get("tasks_per_tres") is not None
                else None,
                "tasks_per_node": V0042Uint16NoValStruct.from_dict(
                    obj["tasks_per_node"]
                )
                if obj.get("tasks_per_node") is not None
                else None,
                "tasks_per_socket": V0042Uint16NoValStruct.from_dict(
                    obj["tasks_per_socket"]
                )
                if obj.get("tasks_per_socket") is not None
                else None,
                "tasks_per_board": V0042Uint16NoValStruct.from_dict(
                    obj["tasks_per_board"]
                )
                if obj.get("tasks_per_board") is not None
                else None,
                "cpus": V0042Uint32NoValStruct.from_dict(obj["cpus"])
                if obj.get("cpus") is not None
                else None,
                "node_count": V0042Uint32NoValStruct.from_dict(obj["node_count"])
                if obj.get("node_count") is not None
                else None,
                "tasks": V0042Uint32NoValStruct.from_dict(obj["tasks"])
                if obj.get("tasks") is not None
                else None,
                "partition": obj.get("partition"),
                "prefer": obj.get("prefer"),
                "memory_per_cpu": V0042Uint64NoValStruct.from_dict(
                    obj["memory_per_cpu"]
                )
                if obj.get("memory_per_cpu") is not None
                else None,
                "memory_per_node": V0042Uint64NoValStruct.from_dict(
                    obj["memory_per_node"]
                )
                if obj.get("memory_per_node") is not None
                else None,
                "minimum_cpus_per_node": V0042Uint16NoValStruct.from_dict(
                    obj["minimum_cpus_per_node"]
                )
                if obj.get("minimum_cpus_per_node") is not None
                else None,
                "minimum_tmp_disk_per_node": V0042Uint32NoValStruct.from_dict(
                    obj["minimum_tmp_disk_per_node"]
                )
                if obj.get("minimum_tmp_disk_per_node") is not None
                else None,
                "power": V0042JobInfoPower.from_dict(obj["power"])
                if obj.get("power") is not None
                else None,
                "preempt_time": V0042Uint64NoValStruct.from_dict(obj["preempt_time"])
                if obj.get("preempt_time") is not None
                else None,
                "preemptable_time": V0042Uint64NoValStruct.from_dict(
                    obj["preemptable_time"]
                )
                if obj.get("preemptable_time") is not None
                else None,
                "pre_sus_time": V0042Uint64NoValStruct.from_dict(obj["pre_sus_time"])
                if obj.get("pre_sus_time") is not None
                else None,
                "hold": obj.get("hold"),
                "priority": V0042Uint32NoValStruct.from_dict(obj["priority"])
                if obj.get("priority") is not None
                else None,
                "priority_by_partition": [
                    V0042PartPrio.from_dict(_item)
                    for _item in obj["priority_by_partition"]
                ]
                if obj.get("priority_by_partition") is not None
                else None,
                "profile": obj.get("profile"),
                "qos": obj.get("qos"),
                "reboot": obj.get("reboot"),
                "required_nodes": obj.get("required_nodes"),
                "required_switches": obj.get("required_switches"),
                "requeue": obj.get("requeue"),
                "resize_time": V0042Uint64NoValStruct.from_dict(obj["resize_time"])
                if obj.get("resize_time") is not None
                else None,
                "restart_cnt": obj.get("restart_cnt"),
                "resv_name": obj.get("resv_name"),
                "scheduled_nodes": obj.get("scheduled_nodes"),
                "selinux_context": obj.get("selinux_context"),
                "shared": obj.get("shared"),
                "sockets_per_board": obj.get("sockets_per_board"),
                "sockets_per_node": V0042Uint16NoValStruct.from_dict(
                    obj["sockets_per_node"]
                )
                if obj.get("sockets_per_node") is not None
                else None,
                "start_time": V0042Uint64NoValStruct.from_dict(obj["start_time"])
                if obj.get("start_time") is not None
                else None,
                "state_description": obj.get("state_description"),
                "state_reason": obj.get("state_reason"),
                "standard_error": obj.get("standard_error"),
                "standard_input": obj.get("standard_input"),
                "standard_output": obj.get("standard_output"),
                "submit_time": V0042Uint64NoValStruct.from_dict(obj["submit_time"])
                if obj.get("submit_time") is not None
                else None,
                "suspend_time": V0042Uint64NoValStruct.from_dict(obj["suspend_time"])
                if obj.get("suspend_time") is not None
                else None,
                "system_comment": obj.get("system_comment"),
                "time_limit": V0042Uint32NoValStruct.from_dict(obj["time_limit"])
                if obj.get("time_limit") is not None
                else None,
                "time_minimum": V0042Uint32NoValStruct.from_dict(obj["time_minimum"])
                if obj.get("time_minimum") is not None
                else None,
                "threads_per_core": V0042Uint16NoValStruct.from_dict(
                    obj["threads_per_core"]
                )
                if obj.get("threads_per_core") is not None
                else None,
                "tres_bind": obj.get("tres_bind"),
                "tres_freq": obj.get("tres_freq"),
                "tres_per_job": obj.get("tres_per_job"),
                "tres_per_node": obj.get("tres_per_node"),
                "tres_per_socket": obj.get("tres_per_socket"),
                "tres_per_task": obj.get("tres_per_task"),
                "tres_req_str": obj.get("tres_req_str"),
                "tres_alloc_str": obj.get("tres_alloc_str"),
                "user_id": obj.get("user_id"),
                "user_name": obj.get("user_name"),
                "maximum_switch_wait_time": obj.get("maximum_switch_wait_time"),
                "wckey": obj.get("wckey"),
                "current_working_directory": obj.get("current_working_directory"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner import (
    V0041OpenapiSlurmdbdConfigRespQosInner,
)


class TestV0041OpenapiSlurmdbdConfigRespQosInner(unittest.TestCase):
    """V0041OpenapiSlurmdbdConfigRespQosInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiSlurmdbdConfigRespQosInner:
        """Test V0041OpenapiSlurmdbdConfigRespQosInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespQosInner`
        """
        model = V0041OpenapiSlurmdbdConfigRespQosInner()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespQosInner(
                description = '',
                flags = [
                    'NOT_SET'
                    ],
                id = 56,
                limits = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits(
                    grace_time = 56,
                    max = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max(
                        active_jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs(
                            accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            count = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count(
                                set = True,
                                infinite = True,
                                number = 56, ), ),
                        tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres(
                            total = [
                                slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                    type = '',
                                    name = '',
                                    id = 56, )
                                ],
                            minutes = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes(
                                per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per(
                                    qos = [
                                        slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    job = [

                                        ],
                                    account = [

                                        ],
                                    user = [

                                        ], ), ),
                            per = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per(
                                node = [

                                    ], ), ),
                        wall_clock = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock(),
                        jobs = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs(),
                        accruing = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing(), ),
                    factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_factor(
                        set = True,
                        infinite = True,
                        number = 1.337, ),
                    min = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min(
                        priority_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold(
                            set = True,
                            infinite = True,
                            number = 56, ), ), ),
                name = '',
                preempt = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt(
                    list = [
                        ''
                        ],
                    mode = [
                        'DISABLED'
                        ],
                    exempt_time = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                priority = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_priority(
                    set = True,
                    infinite = True,
                    number = 56, ),
                usage_factor = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_factor(
                    set = True,
                    infinite = True,
                    number = 1.337, ),
                usage_threshold = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold.v0_0_41_openapi_slurmdbd_config_resp_qos_inner_usage_threshold(
                    set = True,
                    infinite = True,
                    number = 1.337, )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespQosInner(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespQosInner(self):
        """Test V0041OpenapiSlurmdbdConfigRespQosInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_assoc_rec_set import V0040AssocRecSet


class TestV0040AssocRecSet(unittest.TestCase):
    """V0040AssocRecSet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040AssocRecSet:
        """Test V0040AssocRecSet
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040AssocRecSet`
        """
        model = V0040AssocRecSet()
        if include_optional:
            return V0040AssocRecSet(
                comment = '',
                defaultqos = '',
                grpjobs = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                grpjobsaccrue = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                grpsubmitjobs = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                grptres = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                grptresmins = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                grptresrunmins = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                grpwall = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                maxjobs = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                maxjobsaccrue = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                maxsubmitjobs = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                maxtresminsperjob = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                maxtresrunmins = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                maxtresperjob = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                maxtrespernode = [
                    slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                maxwalldurationperjob = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                minpriothresh = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                parent = '',
                priority = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                qoslevel = [
                    ''
                    ],
                fairshare = 56
            )
        else:
            return V0040AssocRecSet(
        )
        """

    def testV0040AssocRecSet(self):
        """Test V0040AssocRecSet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_job_desc_msg import V0040JobDescMsg


class TestV0040JobDescMsg(unittest.TestCase):
    """V0040JobDescMsg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040JobDescMsg:
        """Test V0040JobDescMsg
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040JobDescMsg`
        """
        model = V0040JobDescMsg()
        if include_optional:
            return V0040JobDescMsg(
                account = '',
                account_gather_frequency = '',
                admin_comment = '',
                allocation_node_list = '',
                allocation_node_port = 56,
                argv = [
                    ''
                    ],
                array = '',
                batch_features = '',
                begin_time = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                flags = [
                    'KILL_INVALID_DEPENDENCY'
                    ],
                burst_buffer = '',
                clusters = '',
                cluster_constraint = '',
                comment = '',
                contiguous = True,
                container = '',
                container_id = '',
                cores_per_socket = 56,
                core_specification = 56,
                thread_specification = 56,
                cpu_binding = '',
                cpu_binding_flags = [
                    'CPU_BIND_TO_THREADS'
                    ],
                cpu_frequency = '',
                cpus_per_tres = '',
                crontab = slurmrestpy.models.v0/0/40_cron_entry.v0.0.40_cron_entry(
                    flags = [
                        'WILD_MINUTE'
                        ],
                    minute = '',
                    hour = '',
                    day_of_month = '',
                    month = '',
                    day_of_week = '',
                    specification = '',
                    command = '',
                    line = slurmrestpy.models.v0_0_42_cron_entry_line.v0_0_42_cron_entry_line(
                        start = 56,
                        end = 56, ), ),
                deadline = 56,
                delay_boot = 56,
                dependency = '',
                end_time = 56,
                environment = [
                    ''
                    ],
                rlimits = slurmrestpy.models.v0_0_40_job_desc_msg_rlimits.v0_0_40_job_desc_msg_rlimits(
                    cpu = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    fsize = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    data = ,
                    stack = ,
                    core = ,
                    rss = ,
                    nproc = ,
                    nofile = ,
                    memlock = ,
                    as = , ),
                excluded_nodes = [
                    ''
                    ],
                extra = '',
                constraints = '',
                group_id = '',
                hetjob_group = 56,
                immediate = True,
                job_id = 56,
                kill_on_node_fail = True,
                licenses = '',
                mail_type = [
                    'BEGIN'
                    ],
                mail_user = '',
                mcs_label = '',
                memory_binding = '',
                memory_binding_type = [
                    'NONE'
                    ],
                memory_per_tres = '',
                name = '',
                network = '',
                nice = 56,
                tasks = 56,
                open_mode = [
                    'APPEND'
                    ],
                reserve_ports = 56,
                overcommit = True,
                partition = '',
                distribution_plane_size = 56,
                power_flags = [
                    null
                    ],
                prefer = '',
                hold = True,
                priority = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                profile = [
                    'NOT_SET'
                    ],
                qos = '',
                reboot = True,
                required_nodes = [
                    ''
                    ],
                requeue = True,
                reservation = '',
                script = '',
                shared = [
                    'none'
                    ],
                exclusive = [
                    'true'
                    ],
                oversubscribe = True,
                site_factor = 56,
                spank_environment = [
                    ''
                    ],
                distribution = '',
                time_limit = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                time_minimum = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                tres_bind = '',
                tres_freq = '',
                tres_per_job = '',
                tres_per_node = '',
                tres_per_socket = '',
                tres_per_task = '',
                user_id = '',
                wait_all_nodes = True,
                kill_warning_flags = [
                    'BATCH_JOB'
                    ],
                kill_warning_signal = '',
                kill_warning_delay = slurmrestpy.models.v0/0/40_uint16_no_val.v0.0.40_uint16_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                current_working_directory = '',
                cpus_per_task = 56,
                minimum_cpus = 56,
                maximum_cpus = 56,
                nodes = '',
                minimum_nodes = 56,
                maximum_nodes = 56,
                minimum_boards_per_node = 56,
                minimum_sockets_per_board = 56,
                sockets_per_node = 56,
                threads_per_core = 56,
                tasks_per_node = 56,
                tasks_per_socket = 56,
                tasks_per_core = 56,
                tasks_per_board = 56,
                ntasks_per_tres = 56,
                minimum_cpus_per_node = 56,
                memory_per_cpu = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                memory_per_node = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                temporary_disk_per_node = 56,
                selinux_context = '',
                required_switches = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                    set = True,
                    infinite = True,
                    number = 56, ),
                standard_error = '',
                standard_input = '',
                standard_output = '',
                wait_for_switch = 56,
                wckey = '',
                x11 = [
                    'FORWARD_ALL_NODES'
                    ],
                x11_magic_cookie = '',
                x11_target_host = '',
                x11_target_port = 56
            )
        else:
            return V0040JobDescMsg(
        )
        """

    def testV0040JobDescMsg(self):
        """Test V0040JobDescMsg"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_assoc_max_per import V0042AssocMaxPer


class TestV0042AssocMaxPer(unittest.TestCase):
    """V0042AssocMaxPer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042AssocMaxPer:
        """Test V0042AssocMaxPer
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042AssocMaxPer`
        """
        model = V0042AssocMaxPer()
        if include_optional:
            return V0042AssocMaxPer(
                account = slurmrestpy.models.v0_0_42_assoc_max_per_account.v0_0_42_assoc_max_per_account(
                    wall_clock = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ), )
            )
        else:
            return V0042AssocMaxPer(
        )
        """

    def testV0042AssocMaxPer(self):
        """Test V0042AssocMaxPer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_assoc_shares_obj_wrap_tres import (
    V0040AssocSharesObjWrapTres,
)


class TestV0040AssocSharesObjWrapTres(unittest.TestCase):
    """V0040AssocSharesObjWrapTres unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040AssocSharesObjWrapTres:
        """Test V0040AssocSharesObjWrapTres
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040AssocSharesObjWrapTres`
        """
        model = V0040AssocSharesObjWrapTres()
        if include_optional:
            return V0040AssocSharesObjWrapTres(
                run_seconds = [
                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                        name = '',
                        value = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                group_minutes = [
                    slurmrestpy.models.v0/0/40_shares_uint64_tres.v0.0.40_shares_uint64_tres(
                        name = '',
                        value = slurmrestpy.models.v0/0/40_uint64_no_val.v0.0.40_uint64_no_val(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                usage = [
                    slurmrestpy.models.v0/0/40_shares_float128_tres.v0.0.40_shares_float128_tres(
                        name = '',
                        value = 1.337, )
                    ]
            )
        else:
            return V0040AssocSharesObjWrapTres(
        )
        """

    def testV0040AssocSharesObjWrapTres(self):
        """Test V0040AssocSharesObjWrapTres"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_partition_info import V0042PartitionInfo


class TestV0042PartitionInfo(unittest.TestCase):
    """V0042PartitionInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042PartitionInfo:
        """Test V0042PartitionInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042PartitionInfo`
        """
        model = V0042PartitionInfo()
        if include_optional:
            return V0042PartitionInfo(
                nodes = slurmrestpy.models.v0_0_42_partition_info_nodes.v0_0_42_partition_info_nodes(
                    allowed_allocation = '',
                    configured = '',
                    total = 56, ),
                accounts = slurmrestpy.models.v0_0_42_partition_info_accounts.v0_0_42_partition_info_accounts(
                    allowed = '',
                    deny = '', ),
                groups = slurmrestpy.models.v0_0_42_partition_info_groups.v0_0_42_partition_info_groups(
                    allowed = '', ),
                qos = slurmrestpy.models.v0_0_42_partition_info_qos.v0_0_42_partition_info_qos(
                    allowed = '',
                    deny = '',
                    assigned = '', ),
                alternate = '',
                tres = slurmrestpy.models.v0_0_42_partition_info_tres.v0_0_42_partition_info_tres(
                    billing_weights = '',
                    configured = '', ),
                cluster = '',
                select_type = [
                    'CPU'
                    ],
                cpus = slurmrestpy.models.v0_0_42_partition_info_cpus.v0_0_42_partition_info_cpus(
                    task_binding = 56,
                    total = 56, ),
                defaults = slurmrestpy.models.v0_0_42_partition_info_defaults.v0_0_42_partition_info_defaults(
                    memory_per_cpu = 56,
                    partition_memory_per_cpu = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    partition_memory_per_node = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    time = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    job = '', ),
                grace_time = 56,
                maximums = slurmrestpy.models.v0_0_42_partition_info_maximums.v0_0_42_partition_info_maximums(
                    cpus_per_node = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    cpus_per_socket = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    memory_per_cpu = 56,
                    partition_memory_per_cpu = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    partition_memory_per_node = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    nodes = ,
                    shares = 56,
                    oversubscribe = slurmrestpy.models.v0_0_42_partition_info_maximums_oversubscribe.v0_0_42_partition_info_maximums_oversubscribe(
                        jobs = 56,
                        flags = [
                            'force'
                            ], ),
                    time = ,
                    over_time_limit = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                minimums = slurmrestpy.models.v0_0_42_partition_info_minimums.v0_0_42_partition_info_minimums(
                    nodes = 56, ),
                name = '',
                node_sets = '',
                priority = slurmrestpy.models.v0_0_42_partition_info_priority.v0_0_42_partition_info_priority(
                    job_factor = 56,
                    tier = 56, ),
                timeouts = slurmrestpy.models.v0_0_42_partition_info_timeouts.v0_0_42_partition_info_timeouts(
                    resume = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    suspend = slurmrestpy.models.v0/0/42_uint16_no_val_struct.v0.0.42_uint16_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                partition = slurmrestpy.models.v0_0_42_partition_info_partition.v0_0_42_partition_info_partition(
                    state = [
                        'INACTIVE'
                        ], ),
                suspend_time = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, )
            )
        else:
            return V0042PartitionInfo(
        )
        """

    def testV0042PartitionInfo(self):
        """Test V0042PartitionInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing_extensions import Self


class V0041OpenapiPartitionRespPartitionsInnerSuspendTime(BaseModel):
    """
    SuspendTime (GLOBAL if both set and infinite are false)
    """  # noqa: E501

    set: Optional[StrictBool] = Field(
        default=None,
        description="True if number has been set; False if number is unset",
    )
    infinite: Optional[StrictBool] = Field(
        default=None,
        description='True if number has been set to infinite; "set" and "number" will be ignored',
    )
    number: Optional[StrictInt] = Field(
        default=None,
        description='If "set" is True the number will be set with value; otherwise ignore number contents',
    )
    __properties: ClassVar[List[str]] = ["set", "infinite", "number"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiPartitionRespPartitionsInnerSuspendTime from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiPartitionRespPartitionsInnerSuspendTime from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "set": obj.get("set"),
                "infinite": obj.get("infinite"),
                "number": obj.get("number"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing_extensions import Self


class V0042BfExitFields(BaseModel):
    """
    V0042BfExitFields
    """  # noqa: E501

    end_job_queue: Optional[StrictInt] = Field(
        default=None, description="Reached end of queue"
    )
    bf_max_job_start: Optional[StrictInt] = Field(
        default=None, description="Reached number of jobs allowed to start"
    )
    bf_max_job_test: Optional[StrictInt] = Field(
        default=None, description="Reached number of jobs allowed to be tested"
    )
    bf_max_time: Optional[StrictInt] = Field(
        default=None, description="Reached maximum allowed scheduler time"
    )
    bf_node_space_size: Optional[StrictInt] = Field(
        default=None, description="Reached table size limit"
    )
    state_changed: Optional[StrictInt] = Field(
        default=None, description="System state changed"
    )
    __properties: ClassVar[List[str]] = [
        "end_job_queue",
        "bf_max_job_start",
        "bf_max_job_test",
        "bf_max_time",
        "bf_node_space_size",
        "state_changed",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042BfExitFields from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042BfExitFields from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "end_job_queue": obj.get("end_job_queue"),
                "bf_max_job_start": obj.get("bf_max_job_start"),
                "bf_max_job_test": obj.get("bf_max_job_test"),
                "bf_max_time": obj.get("bf_max_time"),
                "bf_node_space_size": obj.get("bf_node_space_size"),
                "state_changed": obj.get("state_changed"),
            }
        )
        return _obj
